@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #ifndef WORKMODULE_H
 #define WORKMODULE_H
 
@@ -13,6 +17,10 @@
 #include <QPixmap>
 #include <QThread>
 
+QT_BEGIN_NAMESPACE
+class QMutex;
+QT_END_NAMESPACE
+
 class DriverManger;
 class ErollThread : public QThread
 {
@@ -34,6 +42,7 @@ private:
     bool m_bFirst;
 };
 
+
 class VerifyThread : public QThread
 {
 public:
@@ -50,6 +59,7 @@ private:
     QString m_actionId;
     bool m_bRun;
     QVector<float *> m_charaDatas;
+    QSharedPointer<QMutex> m_mutex;
 };
 
 #endif // WORKMODULE_H
